
TODO: TODO_99_87_25_42: next incompatible changes

This is a plan for next incompatible changes - they are primarily renames.

*   TODO: Rename: `relay_server` package to `argrelay_server` (to search `argrelay_server` and find relevant stuff).
*   TODO: Rename: `relay_client` package to `argrelay_client` (to search `argrelay_client` and find relevant stuff).

TODO:
*   Rename all enum items to underscore (e.g. `ServerAction.ProposeArgValues` -> `ServerAction.propse_args_values`).
*   TODO: Rename rest API:
    *   `describe_line_args` -> `query_enum_items` (to match func_id)
    *   `propose_arg_values` -> `complete_line`
    *   `relay_line_args` -> `invoke_line`

*   TODO: Rename `ConfiguratorDefault` to `GuiConfigurator`.
*   TODO: Move all GUI config into `ConfiguratorDefault` (including banner, header and footer).

*   TODO: TODO_19_67_22_89: remove `ignored_func_ids_list` - load as `FuncState.fs_unplugged`.

*   TODO: Shorten name `EnvelopeContainer.filled_prop_values_hidden_by_defaults` to `default_override`-s.
*   TODO: Remove `relay_demo` linked command after creating new screencast with `lay` linked command. 
